// frontend/script.js
const taskForm = document.getElementById('taskForm');
const taskInput = document.getElementById('taskInput');
const taskList = document.getElementById('taskList');

// Function to fetch all tasks from the server
async function fetchTasks() {
    const response = await fetch('/tasks');
    const tasks = await response.json();
    displayTasks(tasks);
}
// Function to display tasks in the UI
function displayTasks(tasks) {
    taskList.innerHTML = '';
    tasks.forEach(task => {
        const li = document.createElement('li');
        li.textContent = task.task;
        if (task.completed) {
            li.classList.add('completed');
        }
        
        // Create delete button
        const deleteButton = document.createElement('button');
        deleteButton.textContent = 'Delete';
        deleteButton.classList.add('deleteButton');
        
        // Add click event listener to delete button
        deleteButton.addEventListener('click', (e) => {
            e.stopPropagation(); // Prevent li click event from firing
            deleteTask(task.id);
        });
        
        li.appendChild(deleteButton); // Append delete button to li
        
        li.addEventListener('click', () => markTaskCompleted(task.id));
        taskList.appendChild(li);
    });
}

// Function to delete a task
async function deleteTask(id) {
    await fetch(`/tasks/${id}`, {
        method: 'DELETE'
    });
    fetchTasks(); // Refresh the task list after deletion
}

// Function to add a new task
async function addTask(task) {
    const response = await fetch('/tasks', {
        method: 'POST',
        headers: {
            'Content-Type': 'application/json'
        },
        body: JSON.stringify({ task })
    });
    fetchTasks();
}

// Function to mark a task as completed
async function markTaskCompleted(id) {
    await fetch(`/tasks/${id}`, {
        method: 'PUT'
    });
    fetchTasks();
}

// Event listener for submitting the task form
taskForm.addEventListener('submit', (e) => {
    e.preventDefault();
    const newTask = taskInput.value.trim();
    if (newTask !== '') {
        addTask(newTask);
        taskInput.value = '';
    }
});

// Fetch tasks when the page loads
fetchTasks();
